/*
 * Copyright (c) 2007, Your Corporation. All Rights Reserved.
 */

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.orchestra.urlParamNav;

import javax.faces.FacesException;
import javax.faces.application.ViewHandler;
import javax.faces.component.UIViewRoot;
import javax.faces.context.FacesContext;
import java.io.IOException;
import java.util.Locale;

/**
 * This view handler helps to preserve any url parameter you configured in your navigation.
 *
 * @see org.apache.myfaces.orchestra.urlParamNav.UrlParameterNavigationHandler
 */
public class UrlParameterViewHandler extends ViewHandler
{
	private final ViewHandler original;

	public UrlParameterViewHandler(final ViewHandler original)
	{
		this.original = original;
	}

	public Locale calculateLocale(FacesContext context)
	{
		return original.calculateLocale(context);
	}

	public String calculateRenderKitId(FacesContext context)
	{
		return original.calculateRenderKitId(context);
	}

	public UIViewRoot createView(FacesContext context, String viewId)
	{
		return original.createView(context, viewId);
	}

	public String getActionURL(FacesContext context, String viewId)
	{
		if (viewId != null)
		{
			int pos = viewId.indexOf('?');
			if (pos > -1)
			{
				String realViewId = viewId.substring(0, pos);
				String params = viewId.substring(pos);

				return original.getActionURL(context, realViewId) + params;
			}
		}
		return original.getActionURL(context, viewId);
	}

	public String getResourceURL(FacesContext context, String path)
	{
		return original.getResourceURL(context, path);
	}

	public void renderView(FacesContext context, UIViewRoot viewToRender)
		throws IOException, FacesException
	{
		original.renderView(context, viewToRender);
	}

	public UIViewRoot restoreView(FacesContext context, String viewId)
	{
		return original.restoreView(context, viewId);
	}

	public void writeState(FacesContext context)
		throws IOException
	{
		original.writeState(context);
	}
}