/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.myfaces.orchestra.viewController;


/**
 * <p>The abstract basis class you have to use as basis class for any custom view controller executor.</p>
 * <p>Notice: This abstract class is a helper as the interface can be extended between releases,
 * thats why its an abstract class instead of an interface.
 * New methods not implemented by your custom excecutor will not harm your system that way
 * if you inherit from this abstract class .</p>
 */
public abstract class AbstractViewControllerExecutor implements ViewControllerExecutor
{
	public boolean invokeInitView(String beanName, Object bean)
	{
		return false;
	}

	public boolean invokePreRenderView(String beanName, Object bean)
	{
		return false;
	}
    
    public boolean invokePreProcess(String beanName, Object bean)
    {
		return false;
    }
}
