/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.myfaces.orchestra.viewController;

/**
 * Route per-view lifecycle events to the correct user methods.
 *
 * <p>The ViewControllerPhaseListener retrieves a concrete implementation of this interface then
 * invokes it at various processing phases. The concrete implementation is responsible for
 * determining which methods on which objects (backing beans) should be invoked.</p>
 *
 * <p>Orchestra provides a couple of different implementations; see
 * {@link DefaultViewControllerManager} and {@link ReflectiveViewControllerExecutor}.</p>
 *
 * <h2>Defining your own ViewControllerManager</h2>
 *
 * <p>If you would like to use your own naming scheme or executor just implement your own {@link ViewControllerManager} or
 * derive from {@link DefaultViewControllerManager} (the recommended way) and overload
 * {@link AbstractViewControllerManager#getViewControllerNameMapper()} or
 * {@link AbstractViewControllerManager#getViewControllerExecutor()} }.</p>
 *
 * <p>To activate your manager just configure it as managed bean in your faces-config.xml or your spring
 * configuration, preferably in application scope or as singleton.</p>
 *
 * <p>The managed-bean-name has to be "<code>org.apache.myfaces.orchestra.viewController.ViewControllerManager</code>"
 * (see constant {@link ViewControllerManager#VIEW_CONTROLLER_MANAGER_NAME})</p>
 */
public interface ViewControllerManager
{
	public final static String VIEW_CONTROLLER_MANAGER_NAME = ViewControllerManager.class.getName();

	public Object getViewController(String viewId);
	public String getViewControllerName(String viewId);

	public void assertConversationState(String viewId);
	public void executeInitView(String viewId);
	public void executePreProcess(String viewId);
	public void executePreRenderView(String viewId);
}
