/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.orchestra.lib.jsf;

import org.apache.myfaces.orchestra.conversation.ConversationManager;

import javax.faces.event.PhaseEvent;
import javax.faces.event.PhaseId;
import javax.faces.event.PhaseListener;
import java.util.Map;

/**
 * Ensure that Orchestra is initialised for the current user.
 * <p>
 * At start of request processing, if this is a new http session then initialise Orchestra
 * for this session.
 */
public class OrchestraInitializationPhaseListener implements PhaseListener
{
	private static final long serialVersionUID = 1L;

	private final static String SYSTEM_INITIALIZED = OrchestraInitializationPhaseListener.class.getName() + ".INITIALIZED";

	public void afterPhase(PhaseEvent event)
	{
	}

	public void beforePhase(PhaseEvent event)
	{
		if (PhaseId.RESTORE_VIEW.equals(event.getPhaseId()))
		{
			initialize(event);
		}
	}

	private void initialize(PhaseEvent event)
	{
		Map sessionMap = event.getFacesContext().getExternalContext().getSessionMap();
		if (sessionMap != null)
		{
			if (!Boolean.TRUE.equals(sessionMap.get(SYSTEM_INITIALIZED)))
			{
				// ensure correct setup of system
				ConversationManager.getInstance();

				sessionMap.put(SYSTEM_INITIALIZED, Boolean.TRUE);
			}
		}
	}

	public PhaseId getPhaseId()
	{
		return PhaseId.RESTORE_VIEW;
	}
}
