/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.myfaces.orchestra.viewController;

import org.apache.myfaces.orchestra.frameworkAdapter.FrameworkAdapter;

/**
 * @see org.apache.myfaces.orchestra.viewController.ViewControllerManager
 */
public abstract class AbstractViewControllerManager implements ViewControllerManager
{
	protected abstract ViewControllerNameMapper getViewControllerNameMapper();
	protected abstract ViewControllerExecutor getViewControllerExecutor();

	public String getViewControllerName(String viewId)
	{
		ViewControllerNameMapper nameMapper = getViewControllerNameMapper();
		return nameMapper.mapViewId(viewId);
	}

	public Object getViewController(String viewId)
	{
		String beanName = getViewControllerName(viewId);
		if (beanName == null)
		{
			return null;
		}

		return FrameworkAdapter.getCurrentInstance().getBean(beanName);
	}

	public void assertConversationState(String viewId)
	{
	}

	public void executeInitView(String viewId)
	{
		String beanName = getViewControllerNameMapper().mapViewId(viewId);
		Object viewController = getViewController(viewId);
		if (viewController != null)
		{
			getViewControllerExecutor().invokeInitView(beanName, viewController);
		}
	}

	public void executePreProcess(String viewId)
	{
		String beanName = getViewControllerNameMapper().mapViewId(viewId);
		Object viewController = getViewController(viewId);
		if (viewController != null)
		{
			getViewControllerExecutor().invokePreProcess(beanName, viewController);
		}
	}

	public void executePreRenderView(String viewId)
	{
		String beanName = getViewControllerNameMapper().mapViewId(viewId);
		Object viewController = getViewController(viewId);
		if (viewController != null)
		{
			getViewControllerExecutor().invokePreRenderView(beanName, viewController);
		}
	}
}